package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````P"(```````!``````````""^````
M`````````$``.``)`$``'0`<``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````=`````````!T``````````0`````````!````
M!0```````````````````````````````````("<````````@)P`````````
M``$```````$````&````4*L```````!0JP$``````%"K`0``````*`4`````
M``!0%0```````````0```````@````8```!HJP```````&BK`0``````:*L!
M```````@`@```````"`"````````"``````````$````!````%@"````````
M6`(```````!8`@```````$0`````````1``````````$`````````%#E=&0$
M````_)0```````#\E````````/R4````````%`$````````4`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````%"K````````4*L!``````!0JP$`
M`````+`$````````L`0````````!`````````"]L:6(V-"]L9"UL:6YU>"UA
M87)C:#8T+G-O+C$`````!````!0````#````1TY5`&,01]%Z?G_U90A@N_SL
M$,DSUW\T!````!`````!````1TY5```````#````!P``````````````/0``
M`$L````$````"````"$0$``%P`2$*`(0!8"&0(2""0`$"2`$B(B@$$6Z``((
M``````````!+`````````$P```!-````3P````````!0`````````%$```!2
M````4P```%0`````````50```%<`````````````````````````````````
M````````6````%D```!;````70```````````````````%X`````````7P``
M``````!@````80````````!B````8P````````!D````90``````````````
M````````````````9@``````````````9P````````!H``````````````!I
M`````````````````````````+OCDGQK&IY0+L6;MD/ZUX<5C"7,9Z_,9F_%
MWQ^)!W#3H^#[2?NA;&``KS3HO]I7&]5DU'S#Y3\L?JF<FZU+X\#B1\8!S]Y'
M+0T4XIXA_^0.X:<""MO-XYY9[Y=Y=U0\E+,!BV\-.I<+V7%8'#-BV^UK"4/6
M0T75[&M_FGP``````````````````````````````````````P`+`'`<````
M`````````````````````P`7``"P`0````````````````!$`@``$@``````
M``````````````````"[`@``$@`````````````````````````4`@``$@``
M```````````````````````;`@``$@````````````````````````"M`@``
M$@````````````````````````"]`0``$@`````````````````````````!
M````(`````````````````````````!L`@``$@``````````````````````
M``"$`@``$@````````````````````````">`@``(@``````````````````
M``````!]`@``$@````````````````````````!D`@``$@``````````````
M``````````!V`@``$0````````````````````````"7````$@``````````
M``````````````#M`@``$@````````````````````````#8````$@``````
M```````````````````5`0``$@`````````````````````````&`@``$@``
M```````````````````````K`0``$@````````````````````````!S`0``
M$0````````````````````````!+`@``$@````````````````````````#G
M````$@````````````````````````!&````$0``````````````````````
M``"[````$@````````````````````````#"`0``$@``````````````````
M``````#1`@``$@`````````````````````````B`@``$@``````````````
M``````````#U````$@````````````````````````";`0``$@``````````
M```````````````?`0``$@````````````````````````"C`0``$@``````
M``````````````````#Q`0``$@`````````````````````````-`@``$@``
M``````````````````````#*`0``$@````````````````````````#3`0``
M$@````````````````````````"W`0``$@````````````````````````!3
M````$@`````````````````````````=````(```````````````````````
M``#_`@``$0````````````````````````#D`@``(0``````````````````
M``````#Y`0``$@````````````````````````##`@``$@``````````````
M```````````R`0``$@`````````````````````````V`@``$@``````````
M``````````````#*`@``$@````````````````````````"2`P``$@``````
M```````````````````P`@``$@````````````````````````"`````$@``
M`````````````````````````0``$@````````````````````````",````
M$@````````````````````````!9`@``$@````````````````````````!2
M`0``$@`````````````````````````:`0``$@``````````````````````
M``!E`0``$@````````````````````````"4`@``$@``````````````````
M``````!C````$@````````````````````````"P````$@``````````````
M``````````!!`0``$@````````````````````````"-`@``$@``````````
M``````````````!O````$@````````````````````````"/`0``$@``````
M``````````````````#_`0``$@````````````````````````#C`@``$0``
M``````````````````````#E`@``$0````````````````````````"4`0``
M$@````````````````````````#)````$@````````````````````````"G
M````$@`````````````````````````I`@``$@``````````````````````
M```L````(`````````````````````````!^`0``$@``````````````````
M``````#D`0``$@````````````````````````#K`0``$@``````````````
M```````````W!```$``8`*#``0````````````````!1!```$@`-`#!3````
M````E`$```````!A`P``$@`-`+`L````````!`````````#@`P``$@`-`!!2
M````````&`$```````"<!```$@`-`+11````````5`````````#'`P``$@`-
M`!`O````````'`````````";`P``$@`-`.`_````````4`$````````M!```
M$0`7`'"P`0``````"`````````!$!```$@`-`#`O````````)`4```````!\
M!```$@`-``0U````````+`$```````"O`P``$``8`*#``0``````````````
M``"N`P``$``8`*#``0````````````````"E!```$@`-`'`]````````:`(`
M``````!G!```$@`-`)0K````````.`````````"``P``$@`-`.0T````````
M(`````````#X`P``$0`/`(!5````````!`````````"Z`P``$@`-`.`N````
M````*`````````#3`P``$@`-`#`V````````.`<```````!1`P``$@`-`%!5
M````````!`````````!O!```$@`-`+0L````````*`(````````'!```$@`-
M`-`K````````X``````````=!```$@`-`-!4````````?``````````\!```
M$``8`*#``0````````````````!R`P``$``8`'BP`0````````````````".
M!```$@`-`%0T````````D`````````#M`P``(``7``"P`0``````````````
M``!;!```$``8`'BP`0````````````````#Q`P``$@`-`,`B````````/```
M``````#K`P``$``7``"P`0````````````````"G`P``$``7`'BP`0``````
M``````````#>`@``$@`-`(`@````````)`(`````````7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)4
M34-L;VYE5&%B;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?9F5T8VAP=@!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?9V5T7W-V`%!E<FQ?;F5W
M6%,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?<&%R<V4`4&5R;%]S
M=E]S971P=@!097)L7W-V7W-E='!V;@!P97)L7V-O;G-T<G5C=`!P97)L7V1E
M<W1R=6-T`'!E<FQ?86QL;V,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`<&5R;%]F
M<F5E`%!E<FQ?<V%F97-Y<VUA;&QO8P!097)L7W-Y<U]I;FET,P!097)L7VYE
M=UA37V9L86=S`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%!,
M7W1H<E]K97D`7U]E<G)N;U]L;V-A=&EO;@!R96%D`&]P96XV-`!L<V5E:S8T
M`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E
M9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O
M<G0`;65M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C
M:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED
M`')E861L:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK
M7V=U87)D`&QI8G!E<FPM-2XS-"YS;P!L:6)P=&AR96%D+G-O+C``;&EB8RYS
M;RXV`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7VQI8F-?8W-U7V9I;FD`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P
M87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA
M7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,3<`````````
M`@`"``(``@`"``(````"``(``@`"``(``@````(```````(``@````(`````
M`````@`"``(````#`````P`"``(``@`"``,```````0``@`"``(````"``(`
M`@`"``````````(````"`````@`````````"`````P`"``(``@`#```````"
M`````P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`````````!``$`.P,``!`````@
M````EY&6!@``!`"[!`````````$``0`A`P``$````"````"7D98&```#`+L$
M`````````0`!`#$#```0`````````)>1E@8```(`NP0```````!0JP$`````
M``,$````````T",```````!8JP$```````,$````````@",```````!@JP$`
M``````,$````````8*L!``````"(KP$```````,$````````4%4```````#0
MKP$```````,$````````T%0```````#@KP$```````,$````````@"``````
M```0L`$```````,$````````B%4````````8L`$```````,$````````D%4`
M```````HL`$```````,$````````F%4````````PL`$```````,$````````
MJ%4````````XL`$```````,$````````L%4```````!`L`$```````,$````
M````N%4```````!(L`$```````,$````````P%4```````!8L`$```````,$
M````````R%4```````!@L`$```````,$````````T%4```````!PL`$`````
M``,$````````2%D```````"0KP$```````$$```)``````````````"8KP$`
M``````$$```,``````````````"@KP$```````$$```/``````````````"H
MKP$```````$$```0``````````````"PKP$```````$$```6````````````
M``"XKP$```````$$```9``````````````#`KP$```````$$```H````````
M``````#(KP$```````$$```I``````````````#8KP$```````$$```V````
M``````````#HKP$```````$$```^``````````````#PKP$```````$$``!"
M``````````````#XKP$```````$$``!'``````````````"@K0$```````($
M```#``````````````"HK0$```````($```$``````````````"PK0$`````
M``($```%``````````````"XK0$```````($```&``````````````#`K0$`
M``````($```'``````````````#(K0$```````($```(``````````````#0
MK0$```````($```*``````````````#8K0$```````($```+````````````
M``#@K0$```````($```,``````````````#HK0$```````($```-````````
M``````#PK0$```````($```.``````````````#XK0$```````($```1````
M````````````K@$```````($```2```````````````(K@$```````($```3
M```````````````0K@$```````($```4```````````````8K@$```````($
M```5```````````````@K@$```````($```7```````````````HK@$`````
M``($```8```````````````PK@$```````($```:```````````````XK@$`
M``````($```;``````````````!`K@$```````($```<``````````````!(
MK@$```````($```=``````````````!0K@$```````($```>````````````
M``!8K@$```````($```?``````````````!@K@$```````($```@````````
M``````!HK@$```````($```A``````````````!PK@$```````($```B````
M``````````!XK@$```````($```C``````````````"`K@$```````($```D
M``````````````"(K@$```````($```E``````````````"0K@$```````($
M```F``````````````"8K@$```````($```G``````````````"@K@$`````
M``($```H``````````````"HK@$```````($```K``````````````"PK@$`
M``````($```L``````````````"XK@$```````($```M``````````````#`
MK@$```````($```N``````````````#(K@$```````($```O````````````
M``#0K@$```````($```P``````````````#8K@$```````($```Q````````
M``````#@K@$```````($```R``````````````#HK@$```````($```S````
M``````````#PK@$```````($```T``````````````#XK@$```````($```U
M````````````````KP$```````($```W```````````````(KP$```````($
M```X```````````````0KP$```````($```Y```````````````8KP$`````
M``($```Z```````````````@KP$```````($```[```````````````HKP$`
M``````($```\```````````````PKP$```````($```]```````````````X
MKP$```````($```_``````````````!`KP$```````($``!`````````````
M``!(KP$```````($``!#``````````````!0KP$```````($``!$````````
M``````!8KP$```````($``!%``````````````!@KP$```````($``!&````
M``````````!HKP$```````($``!(``````````````!PKP$```````($``!)
M``````````````!XKP$```````($``!*``````````````!?)`/5_7N_J?T#
M`)&@`0"4_7O!J,`#7]8``````````/![OZG0``"P$<Y&^1!B-I$@`A_6'R`#
MU1\@`]4?(`/5T```L!'21OD0@C:1(`(?UM```+`1UD;Y$*(VD2`"'];0``"P
M$=I&^1#"-I$@`A_6T```L!'>1OD0XC:1(`(?UM```+`1XD;Y$`(WD2`"'];0
M``"P$>9&^1`B-Y$@`A_6T```L!'J1OD00C>1(`(?UM```+`1[D;Y$&(WD2`"
M'];0``"P$?)&^1""-Y$@`A_6T```L!'V1OD0HC>1(`(?UM```+`1^D;Y$,(W
MD2`"'];0``"P$?Y&^1#B-Y$@`A_6T```L!$"1_D0`CB1(`(?UM```+`1!D?Y
M$"(XD2`"'];0``"P$0I'^1!".)$@`A_6T```L!$.1_D08CB1(`(?UM```+`1
M$D?Y$((XD2`"'];0``"P$19'^1"B.)$@`A_6T```L!$:1_D0PCB1(`(?UM``
M`+`1'D?Y$.(XD2`"'];0``"P$2)'^1`".9$@`A_6T```L!$F1_D0(CF1(`(?
MUM```+`1*D?Y$$(YD2`"'];0``"P$2Y'^1!B.9$@`A_6T```L!$R1_D0@CF1
M(`(?UM```+`1-D?Y$*(YD2`"'];0``"P$3I'^1#".9$@`A_6T```L!$^1_D0
MXCF1(`(?UM```+`10D?Y$`(ZD2`"'];0``"P$49'^1`B.I$@`A_6T```L!%*
M1_D00CJ1(`(?UM```+`13D?Y$&(ZD2`"'];0``"P$5)'^1"".I$@`A_6T```
ML!%61_D0HCJ1(`(?UM```+`16D?Y$,(ZD2`"'];0``"P$5Y'^1#B.I$@`A_6
MT```L!%B1_D0`CN1(`(?UM```+`19D?Y$"([D2`"'];0``"P$6I'^1!".Y$@
M`A_6T```L!%N1_D08CN1(`(?UM```+`1<D?Y$(([D2`"'];0``"P$79'^1"B
M.Y$@`A_6T```L!%Z1_D0PCN1(`(?UM```+`1?D?Y$.([D2`"'];0``"P$8)'
M^1`"/)$@`A_6T```L!&&1_D0(CR1(`(?UM```+`1BD?Y$$(\D2`"'];0``"P
M$8Y'^1!B/)$@`A_6T```L!&21_D0@CR1(`(?UM```+`1ED?Y$*(\D2`"'];0
M``"P$9I'^1#"/)$@`A_6T```L!&>1_D0XCR1(`(?UM```+`1HD?Y$`(]D2`"
M'];0``"0$:9'^1`B/9$@`A_6T```D!&J1_D00CV1(`(?UM```)`1KD?Y$&(]
MD2`"'];0``"0$;)'^1""/9$@`A_6T```D!&V1_D0HCV1(`(?UM```)`1ND?Y
M$,(]D2`"'];0``"0$;Y'^1#B/9$@`A_6`````````````````````/U[NJG#
M``"0_0,`D6/D1_GS4P&I]5L"J>*'`ZGBXP"1X0,!D>!/`+G@,P&19`!`^>0O
M`/D$`(#2BO__E\```)#"``"0`/1'^4+L1_GA`P*J)`T`E,```)``W$?Y``!`
M.0`*`#33``"PU```D)3:1_F``D"Y4___EP(H4CE"`!\R`B@2.8`"0+E.__^7
MX0,`JN)/0+E`$``15`P`$2(H4CD`?'V30@``,B(H$CE!__^7XP,`JN8C0/G`
M``"P8@("D>5/0+D$.$#Y`0``\,<`0/DAX"21````\```)9%G!`"I0P0`^60`
M`:F_!`!Q+0D`5"$`@-(?(`/5(`P`$<1X8?@A!`"19-@@^+\``6ML__]4I0P`
M$74"`I%_V"7XX@,4*@$``)`$`(#2(8`LD:`.0/F`__^7]`,`*L`$`#1U`@*1
M]E,!D:`.0/G^_O^7````\.$#%JH``!N1@@``E"`$`+1S`@*18`Y`^>;^_Y=E
M__^7P```D`#D1_GA+T#Y`@!`^2$``NL"`(#2P00`5.`#%"KS4T&I]5M"J?U[
MQJC``U_6_/[_E],``+!B`@*10`P`^4`#`+34``"0SO[_EX#:1_D``$"Y__[_
MEQ_<*#FH__\7H`Y`^7/__Y?T`P`JV/__%Z`*0/E@``"T7@<`E-W__Q?A`Q:J
M````\`!`&9%9``"4H`H`^>#Z_[16!P"4U?__%X4`@%+`__\7(`"`4IG^_Y?X
M_O^7'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U5\D`]4=`(#2'@"`TN4#
M`*KA`T#YXB,`D>8#`)'```"0`/!'^<,``)!CZ$?YQ```D(3$1_F__O^7\O[_
ME\```)``X$?Y0```M.K^_Q?``U_6P```L`#@`9'!``"P(>`!D3\``.O```!4
MP0``D"'(1_EA``"T\`,!J@`"'];``U_6P```L`#@`9'!``"P(>`!D2$``,LB
M_'_300R!BR'\09/!``"TP@``D$+\1_EB``"T\`,"J@`"'];``U_6'R`#U?U[
MOJG]`P"1\PL`^=,``+!@XD$Y0`$`-<```)``S$?Y@```M,```)``@"V18?[_
ME]C__Y<@`(!28.(!.?,+0/G]>\*HP`-?UA\@`]4?(`/5W/__%Q\@`]4?(`/5
M'R`#U?U[O*G]`P"1\U,!J:`&`+3W8P.I]P,`JL```)``^$?Y&`!`^3@&`+3U
M6P*I]@,!JA4`@%+@`D`Y'_0`<0080'K!`@!4$P-`^=,!`+2U?D"3]`,8JA\@
M`]7B`Q6JX0,7JN`#$ZIG_O^7@```-6!J=3@?]`!Q``(`5)..0/CS_O^U]5M"
MJ?=C0ZG@`Q.J\U-!J?U[Q*C``U_6]0,7JJ`>0#@?]`!Q!!A`>J'__U2U`A=+
MY?__%Y0"&,NU!@"1<P(5BY3^0Y/4`@"YX`,3JO-30:GU6T*I]V-#J?U[Q*C`
M`U_6$P"`TNG__Q<3`(#2]V-#J>;__Q?]>[.IP0``D/T#`)$AY$?Y(@!`^>)G
M`/D"`(#2P```M/-3`:GS`P"J`0!`.6$!`#7S4T&IP```D`#D1_GA9T#Y`@!`
M^2$``NL"`(#2(0D`5/U[S:C``U_6"?[_E_0#`*J`_O^T]V,#J1<``/#X(P&1
M]X(7D?5;`JG@`Q2JD/[_EV`%`+0!3$`Y%4P`D3^X`'%A``!4H09`.0'__S0`
M3$`Y'[@`<4`%`%3@`Q.JV/W_E_8#`*K@`Q6JU?W_E\`"``L`"``1`'Q`DP'^
M_Y?E`Q6JY`,3JN,#%ZKU`P"J`@"`DB$`@%+._?^7X@,8JN$#%:H``(!2TOW_
MEQ\$`#&@``!4X%M`N0`,%!(?$$!QP`(`5.`#%:J:_O^7X`,5JF#^_Y?@`Q2J
M9O[_E^#Z_[7@`Q2J&_[_E^`#$ZI%_O^7\U-!J?5;0JGW8T.IN___%Z`&0#D?
MN`!QH?K_5*`*0#G@^/\TTO__%^`#%:JF__^7Z___%_-3`:GU6P*I]V,#J0S^
M_Y?]>[6IPP``D.$#`*K]`P"18^1'^?,+`/GBHP"1\P,`JF0`0/GD5P#Y!`"`
MT@``@%(W_O^7(`(`->$[0+D"`)12(0P4$C\00'$D$$)ZH`$`5,$``)`AY$?Y
MXE=`^2,`0/E"``/K`P"`TH$!`%3S"T#Y_7O+J,`#7]8``(!2]?__%^`#$ZI!
M`(!2_?W_EQ\``''@%Y\:[___%^7]_Y?]>[ZI_0,`D?,+`/GS`P"J>/W_EP($
M`-%B`@*+?P("ZZ,``%0P```40@0`T7\"`NL``@!40`!`.1^\`'%@__]4?P("
MZP(%`%1"!`#1?P("ZP`!`%0?(`/50`!`.1^\`''@`0!40@0`T7\"`NMA__]4
M8`)`.1^\`''``P!4\PM`^0```/#]>\*H`*`7D;G]_Q=``$`Y'[P`<8$``%1"
M!`#1?P("ZV/__U1"`!/+``"`TD$(`)$_!$#Q"`$`5,```+`$@`*10@0`D>$#
M$ZK@`P2J`P""TGO]_Y?S"T#Y_7O"J,`#7]9_`@+KH?W_5.'__Q?S"T#Y````
M\/U[PJ@`0!:1G/W_%PP(@M+_8RS+PP``D.+_@=+]>P"I_0,`D6/D1_GS4P&I
M]`,`JO5;`JGUXP"1]@,!JF``0/G@'PCY``"`TN$#%:H```#P`,`7D3G]_Y<?
M``!QC0(`5`,$`%&ARF,XH00`-0,"`#1S?$"3X`,5JN(#$ZKA!8!2XOW_ET`!
M`+3```"0`-A'^0``0+EQ_?^7XP,3JN(#%:KA`Q2JX?W_EP@``!3```"0`-A'
M^0``0+EH_?^7X@,6JN$#%*I)_?^7P```D`#D1_GA'TCY`@!`^2$``NL"`(#2
M(0$`5`P(@M+]>T"I\U-!J?5;0JG_8RR+P`-?UN,#`"K<__\79?W_E_U[NJG"
M``"0_0,`D?-3`:GS`P"J]`,!JO5;`JGW8P.I0N1'^2``0#E!`$#YX2\`^0$`
M@-(?]`!QE!:4FN`#%*KL_/^7]@,`JN%3`9'@`Q.JJ/[_ET`(`+3U`P"JY?S_
ME]\"`.OI!@!4]U>`N=@``)#W\GW38`)`.1_T`'$$&$!Z0`P`5.,#$ZIB'$`X
M7_0`<4080'JA__]48P`3RV-\0),8^T?YP`H`D0```XL6`T#Y`/W_E\!J-_C`
M`@"TXU>`N>`#$ZH"`T#Y`11`.$-X8_@_]`!Q)!A`>F$``#G```!4`A1`.&(<
M`#A?]`!Q1!A`>H'__U2A!X!2``"`TF$4`#B":F`X8F@@.``$`)&B__\UP```
MD`#D1_GA+T#Y`@!`^2$``NL"`(#2H0<`5/-30:GU6T*I]V-#J?U[QJC``U_6
M`0"`TA\@`]6":F$XHFHA."$$`)&B__\U[O__%]@``)#Y:P2I`/M'^1H`0/E`
M`T#Y``4`M.`#&JH5`(!2'R`#U0&,0/CB`Q4JM08`$:'__[5`#``1`'Q]D\$`
M`+`B@$"Y(@(`-2(`@%(B@`"YP?S_E_D#`*J``P"TMWY]D^$#&JKB`Q>J@_S_
MEP#[1_D9``#YH`8`$3_;(/CU5P"Y^6M$J:7__Q?A`P"JX`,:JMW\_Y?Y`P"J
M`?M'^2```/E``0"TMWY]D_/__Q<#`(#2I?__%P`"@-(5`(!2X/__%_EK!*G<
M_/^7^6M$J;K__Q<?(`/5_7N^J?T#`)'S"P#YTP``D'/:1_E@`D"YPOS_EV`"
M0+G`_/^7P@``D",``/`!``#P8R`3D4+41_DA`!B1_?S_EV`"0+FW_/^7\PM`
M^00``/#]>\*HA,`DD>,#!*H"``"P`0``\$+`-9$A@!B1!0"`4@S]_Q?]>[^I
MP```D/T#`)$`V$?Y``!`N:;\_Y?]>\&HP@``D",``/`!``#P0M1'^6,@$Y$A
M`!B1XOS_%Q\@`]4,"H32_V,LR\```)`!"(+2_7L`J?T#`)$`Y$?Y\U,!J?/C
M`)'U$P#Y]6,ABQ0`@-(!`$#YX2<0^0$`@-)A_/^7Y`,`*@4``/`#``#PI>`8
MD6,`&9$B`(+2(0"`4N`#$ZHP_/^7X`,3JN$#%:H"`(+2./S_EX`!^#?S`P"J
M``0`$0!\0)-3_/^7]`,`JL```+1S?D"3X0,5JN(#$ZH1_/^7GVHS.,```)``
MY$?YX2=0^0(`0/DA``+K`@"`T@$!`%3@`Q2J#`J$TOU[0*GS4T&I]1-`^?]C
M+(O``U_6=?S_E\C__Q<,'(+2_V,LR\(``)#]>P"I_0,`D4+D1_GS4P&I\P,!
MJO5;`JGA4P&1]0,`JD,`0/GC;PCY`P"`T@```/``0!F1N_W_E_0#`*KA!8!2
MX`,5JK/\_Y=@`@"TX0,5J@```/``@!F1]O[_E^`#%:K!``"0(>1'^>)O2/DC
M`$#Y0@`#ZP,`@-+!#`!4#!R"TOU[0*GS4T&I]5M"J?]C+(O``U_6X`,5JO=C
M`ZGA^_^7%P``\/@#`"KAPAF1X`,3JMC[_Y?S`P"J@`H`M/9C`Y'Y:P2I&@``
M\!D``/!:0Q:1.:,7D1\@`]5@`D`Y@`8`-+0``+3A`Q.JX`,4JE7\_Y?@!``T
MX`,3JLK[_Y<"!`!1XP,`JF#"(HMARF(X/[P`<2$!`%0?(`/5XP,"*D($`%$?
M```Y8,(BBV'*8C@_O`!Q0/__5``'`!$#``,+?_P_<0P#`%3D`Q.JY@,5JN4#
M&:H#``#P8^`9D0(`@M(A`(!2X`,6JK/[_Y?B8P&1X0,6J@``@%*W^_^7H```
M->!K0+D`#!02'R!`<6`"`%3APAF1``"`TI_[_Y?S`P"JX/G_M?=C0ZGY:T2I
MJ?__%Y0``+2``D`Y'[@`<8```%3S`QJJ(P"`4MS__Q>`!D`Y`/[_-/O__Q?@
M`Q:J(0"`4@W\_Y=@_?\UX0,6J@```/``@!F1D/[_E^`#%JKJ^_^7]V-#J?EK
M1*F7__\7]V-#J9#__Q?W8P.I^6L$J>K[_Y<?(`/5`@!`.>$#`*KB```T'R`#
MU2$$`)%?O`!Q`!"!FB(`0#F"__\UP`-?UA\@`]4?(`/5@```M`$`0#E!```T
M]?W_%P```/``0!:1SOO_%Q\@`]7]>[>IP@``D"$``/#]`P"10N1'^2$@$Y'S
M4P&I%```\/-S`9'U6P*IU0``D)0"&I'W8P.I^2,`^;7Z1_E&`$#YYD<`^08`
M@-(F'$&IYA\&J2040JGD%P>I(6!`>>$#`7GA`Q.JX`,4JA+]_Y?@`0"TH@)`
M^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2J
M!/W_EV#^_[75``"0%```\)1"&I&U^D?YX0,3JN`#%*K\_/^7X`$`M*("0/GC
M7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JN[\
M_Y=@_O^UM0``\!0``-"48AJ1M?I'^>$#$ZK@`Q2JYOS_E^`!`+2B`D#YXU^`
MN4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%*K8_/^7
M8/[_M;4``/`4``#0E*(:D;7Z1_GA`Q.JX`,4JM#\_Y?@`0"TH@)`^>-?@+E`
M#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q2JPOS_EV#^
M_[6U``#P%```T);"&I&U^D?YX0,3JN`#%JJZ_/^7X`$`M*("0/GC7X"Y0`P#
MBP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,6JJS\_Y=@_O^U
MM@``\!4``-"U`AN1UOI'^>$#$ZK@`Q6JI/S_E^`!`+3"`D#YXU^`N4`,`XL!
M!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#%:J6_/^78/[_M;8`
M`/`5``#0MT(9D=;Z1_GA`Q.JX`,7JH[\_Y?@`0"TP@)`^>-?@+E`#`.+`01`
M^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`Q>J@/S_EV#^_[6W``#P
M%@``T-A"&Y'W^D?YX0,3JN`#&*IX_/^7X`$`M.("0/GC7X"Y0`P#BP$$0/E!
M>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8JFK\_Y=@_O^UN```\!<`
M`-#Y@AN1&/M'^>$#$ZK@`QFJ8OS_E^`!`+0"`T#YXU^`N4`,`XL!!$#Y07@C
M^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#&:I4_/^78/[_M;D``/`8``#0
M&,,;D3G[1_GA`Q.JX`,8JDS\_Y?@`0"T(@-`^>-?@+E`#`.+`01`^4%X(_CA
M_O^T`0A`^0$$`/D`(`"1H?__M>$#$ZK@`QBJ/OS_EV#^_[6Y``#P&```T!B#
M&9$Y^T?YX0,3JN`#&*HV_/^7X`$`M"(#0/GC7X"Y0`P#BP$$0/E!>"/XX?[_
MM`$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8JBC\_Y=@_O^UX0,3J@```-```!R1
M(_S_E^$#`*I@``"TX((;D6/]_Y?A`Q.J````T`!@')$;_/^7X0,`JH```+0`
M``#0`&`6D5K]_Y?A`Q.J````T`#`')$2_/^7X0,`JH`"`+2@0AF14OW_EX#"
M&I$!``#0(:`=D4[]_Y>@``#P`.1'^>%'0/D"`$#Y(0`"ZP(`@-+A`P!4\U-!
MJ?5;0JGW8T.I^2-`^?U[R:C``U_6X0,3J@```-```!V1^?O_E^$#`*J```"T
MP$(;D3G]_Y?G__\7`2J(TN(31_A!ZJOR88C)\J$HZ/)?``'K`?S_5.&31WC`
MJ8=2/P``:X'[_U3`0AN1X>\!D2K]_Y?8__\7C/K_E_U[O:FA``#P_0,`D2'D
M1_GS"P#YTP``D"(`0/GB%P#Y`@"`TF`*0+D?!``Q8`$`5*$``/`AY$?YXA=`
M^2,`0/E"``/K`P"`TB$"`%3S"T#Y_7O#J,`#7];ADP"1````T`!`&Y'*^_^7
MX0,`J@``@%*A``"T(`!`.1_``'$$&$!ZX`>?&F`*`+GJ__\7:/K_E_U[OZG]
M`P"1%?K_EXCZ_Y=```"T``!`^?U[P:C``U_6_7N\J:(``/#]`P"10N1'^?-3
M`:GATP"1]5L"J14``-"VPAV10P!`^>,?`/D#`(#2]`,`JN`#%JJI^_^7@```
MM`$`0#GS`P"JP0$`-:```/``Y$?YX1]`^0(`0/DA``+K`@"`TB$&`%3A`Q2J
MH,(=D?-30:GU6T*I_7O$J-S\_Q?A`Q2JJOK_EX`!`+2@``#P`.1'^>$?0/D"
M`$#Y(0`"ZP(`@-(A!`!4\U-!J?5;0JG]>\2HP`-?UN`#%*K(^?^7]0,`JN`#
M$ZK%^?^7H`(`BP`(`)'R^?^7Y@,3J@(`@)(A`(!2Y`,4JO,#`*H%``#0`P``
MT*7`&9%CX!F1O/G_EZ(``/!"Y$?YX!]`^4$`0/D```'K`0"`TH$``%3A`Q.J
MX`,6JM/__Q<5^O^7##:0TO]C+,NA``#P_7L!J?U#`)$AY$?Y]V,$J=<``)#B
M(@"1\U,"J?3S`9'U6P.I]@,`JN`C0)$F`$#Y!M0`^08`@-(8``#01)1`J>07
M"*GA`Q2J2BQ"J0!#&9%()$.IZB\+J48<1*GH)PRI1!1%J>27":E,#$#Y[$L`
M^4(P0/GB5P#YYA\-J4K[_Y>```"T`0!`.?,#`*HA(0`U^6L%J?MS!JF;^?^7
M#OK_ET`<`+09`$#Y&1P`M.`#&:I]^?^7`/A_TP`$`)&J^?^7)`-`.?4#`*JD
M`0`T&@``T/,#%:I:(QZ1'R`#U>`#$ZKC`QJJ`@"`DB$`@%)R^?^7<PH`D20?
M0#@D__\U`0``T/GC`I$@8!:1`P``%""'0/C`"0"TX0,4JB/[_Y?S`P"J8/__
MM`$`0#DA__\TN_O_E^#^_S3@`Q.JN_G_E_,#`*I`"`"TX`,3JE?Y_Y?Z`P"J
MX`,5JE3Y_Y=:`P`+6A,0$1D``-!:?T"3X`,:JG[Y_Y?G`Q6JY`,3JB6C%Y$&
M``#0`P``T,9`'I%C8!Z1`@"`DOL#`*HA`(!21_G_E^`#&ZH!.(!2(/K_EQ\$
M`#&A``!4%?K_EP4`0+F_1`!Q018`5.*#`Y'A`QNJ``"`4M;Y_Y?S`P`J``8`
M-*```/`"``#0PP)`^>0#&ZH`T$?Y0J`?D2$`@%(5`(#2``!`^:[Y_Y>@``#P
MX2-`D0#D1_DBU$#Y`P!`^4(``^L#`(#2`2@`5.`#%:H,-I#2_7M!J?-30JGU
M6T.I]V-$J?EK1:G[<T:I_V,LB\`#7];Z`P*1&0"`4A\@`]53VWGXLP$`M&`"
M0#E@`0`T.0<`$>`#$ZIK^_^7(/__-.`#$ZIK^?^7\P,`JB#V_[53VWGXL_[_
MM1,`@-*M__\7X/-`N0`,%!(?$$!QP?G_5/7[0+D7^?^7OP(`:T'Y_U3@\T"Y
M`"``$A\`!W'!^/]4X`,:JB?Y_Y<!``#0]0,`JB``(9'A`Q2JLOK_EZ`0`+3:
M`D#Y3_G_E^$#`*K@`QJJX?S_E_P#`*K`#P"TX`,<JNCX_Y?Z`P"J'PP`<>T!
M`%0`?$"3`0``T``0`-$A("&1@`,`BV?Y_Y<``0`U7Q,`<8`9`%1:%P!1@,MZ
M.!^\`'$`&0!4'R`#U>`*0+D?!``Q0`T`5!0``-!`#@`T@$(;D0$``-`AH!V1
MTOO_ESFC%Y$4``#0E,(DD18``-#U^/^7UN(AD>8#`"KG`Q2JY0,9JN0#&ZK@
M`Q6J`P``T`(`@))CH"&1(0"`4L+X_Y<1```4E/G_EP``0+D?1`!Q00(`5.3X
M_Y?T`P#Y<P8`$>8#`"KG`Q,JY0,9JN0#&ZKC`Q:JX`,5J@(`@)(A`(!2L?C_
ME^`#%:H!.(!2BOG_EQ\$`#&`_?]4X`,;JDKY_Y?A`Q6J`$,9D:?[_Y?@`Q6J
MJO[_EW?__Q?U8P*1$P"`4A\@`]6@VG/X@`$`M.$#%*IS!@`16/K_EV#__[0!
M`$`Y(?__-/3X_Y?Y`P"J@.+_M:#:<_C`_O^UH`&`TK[X_Y<9``#0]0,`JCD#
M'I%D"H!2$___%Z```/#D`QNJPP)`^0(``-``T$?Y0J`>D2$`@%(5`(#2``!`
M^0/Y_Y=5__\7AO[_EZ```/#A(T"1`.1'^2+40/D#`$#Y0@`#ZP,`@-*!$@!4
MX`,3J@PVD-+]>T&I\U-"J?5;0ZGW8T2I_V,LB\WX_Q?<`D#Y@O__%^$#%*H4
M``#0@$(;D2?Z_Y>@``"T``!`.1_``'$$&$!ZX0D`5/\*`+G@`QRJ`0"`4A0`
M`-`E^?^7]@,`*D#Q_S1"`(!2(0*`DO.C!I&G^/^7X0,3JN`#%BK"`(#2$_G_
ME^"C1CF````UX*=&.1\,`7&`"0!4`@"`4@$`@-+@`Q8JFOC_EWX%`)3T`P"J
M!0``%.(#`"KA`Q.JX`,4JH\%`)3A`Q.JX`,6*@(`D-+_^/^7'P``<>S^_U3@
M`Q8J\X,%D:;X_Y?\XP61X0,4JAH``-#V`Q.J]`,<JI>C`)%:(QZ1X`,3JL4%
M`)3$%D`XX`,4JN,#&JJ4"@"1`@"`DB$`@%(N^/^7_P(4ZP'__U3F`QRJ):,7
MD>0#&ZH'``#0`P``T.?`))%C8"&1`@"`DB$`@%+@`Q6J_X,&.2#X_Y?@`QNJ
MOOC_E^$#%:H`0QF1&_O_E^`#%:H>_O^7Z_[_%R``@%+@"@"Y0/__%]8&0/DV
MY_^TX`,6J@WX_Y<?#`#QJ>;_5``0`-$!``#0P`(`BR%`(9&.^/^7'P``<9P3
MEIHM__\7X*M&.1\$`7%A]O]4X*]&.1\,`7$!]O]4X+-&.1\@`7&A]?]4X+=&
M.1\4`7%!]?]4X`,6*D(`@%(A!X"20_C_E^$#$ZK@`Q8J(@6`TJ_X_Y?F`Q.J
M):,7D>0#&ZK@`Q6J!P``T`,``-#GP"218V`AD0(`@)(A`(!2Z/?_ESS__Q=*
M^/^7^6L%J?MS!JE'^/^7'R`#U1\@`]7]>[NIH0``\/T#`)'S4P&ILP``\/5;
M`JGV$P&1==I'^?=C`ZDAY$?YH`)`N2(`0/GB)P#Y`@"`TB;X_Y?T`P"JH`)`
MN2/X_Y?B`P"J@\)".0```-#A`Q:J`,`:D4/$`CF$^?^7@```M`$`0#D_Q`!Q
M@`L`5%/\_Y=UVD?YH`)`N13X_Y<!``#08P"`4B%`(I$B`(!2)_C_E_0#`*J`
M`0"TH`)`N0OX_Y>!"D#Y`@``T$)@(I$A`$#YZO?_EX`*0/D``$#Y``Q`N2`+
ML#=WVD?YU0``D.`"0+G^]_^7`0``T&,`@%(A@"*1(@"`4A'X_Y?T`P"JH`$`
MM.$#%JH```#0`(`9D5OY_Y?X`P"JX`)`N?@'`+3O]_^7@0I`^>(#&*HA`$#Y
MS_?_EW/:1_FW`@*18`)`N>?W_Y?T`P"J8`)`N>3W_Y<B`(!2`0``T"&@(I$<
M^/^7`@``T.$#`*I"`".1X`,4JK_W_Y=@`D"YV??_E^(#`*KA`Q:J````T`!`
M&9%?Q`(Y._G_E^`*`/GS`P"JX`(`M`$X@%+@`Q.J5?C_EP$$`!$_!`!Q!(A1
M>N$$`%2@``#P`.1'^>$G0/D"`$#Y(0`"ZP(`@-+A`P!4\U-!J?5;0JGW8T.I
M_7O%J,`#7]8`!$`YH/3_-*/__Q?@!D#YM/W_E^`*`/GS`P"JP/S_M0```-``
M(".1\O?_E['W_Y>@`@*1@@I`^0$$0/E``$#Y(0!`^1CZ_Y?`__\7H`)`N:CW
M_Y>!"D#Y(0!`^?WW_Y>C__\7L_?_E[4"`I'C`P`JX@,3J@```-``P".1H09`
M^2$`0/G;]_^7'R`#U1\@`]7]>[RIH0``\/T#`)$AY$?Y\U,!J?0#`*KU6P*I
M(@!`^>(?`/D"`(#2P`8`M`$`0#F!!@`TM_G_EP$`0#GS`P"JX0``-!\@`]4`
M!`"1/[P`<7,2@)H!`$`Y@?__-;8``/"?`@#Q]0>?&L`*0+D?!``Q``4`5!\`
M`''@!Y\:M0(`"I4!`#6@``#0`.1'^>$?0/D"`$#Y(0`"ZP(`@-*!!0!4\U-!
MJ?5;0JG]>\2HP`-?UH`"0#F`_O\T`0``L.`#$ZHA0!Z1@@"`TD[W_Y?`_?\U
MH```T`#D1_GA'T#Y`@!`^2$``NL"`(#2(0,`5.`#%*KS4T&I]5M"J?U[Q*C^
M^/\7````L`!`%I%>]_^7R___%P```+#ATP"1`$`;D;GX_Y>@``"T``!`.1_`
M`'$$&$!Z80``5-\*`+G3__\7(`"`4L`*`+D5^O\TVO__%U7W_Y?_@PK1H0``
MT.)C`)$%X`"1".`!D>0#`JK]>P"I_0,`D2'D1_DC`$#YXT\!^0,`@-*A`$"Y
MA$``D:.$0/@A",!:@0`?^&'\8--G_&C3YQQXDB;<>-,A'`A3QAQPDN/@0ZHA
M``:J(0`#JH&`'_@?`07K`?[_5$4`")%!`$#Y0B``D4,$0/E$'$#Y8P`!RD$P
M0/DA``3*(0`#RB/\7]-A!`&J(7Q`DD$\`/E?``7K8?[_5`<H0*DD,X_2""1!
MJ410J_+EFT&I(W2=TN+\6]/L_$+30A0'JHQY!ZHA`0C*(]NM\B$`"HHA``G*
MI0`$BR)`(HM!_4+3(7@*JD(`!8L+$$#Y+7Q`DJ4!",K&``2+0@`+"Z4`!XJE
M``C*(0`,RD[\6]-/_$+3I0`)B\X5`JJE``:+(0`"BN)Y`JJE``X+YK]"J2$`
M#<JN_%O3(0`(B\X5!:JP_$+3Q@`$B^\!!(LA``:+A@$"RB$`#@N,?4"2Q@`%
MBL8`#,HN_%O3Q@`-B\X5`:H->@6JQ@`/B\8`#@M%``W*[A]`^4)\0)*E``&*
M,/Q"TZ4``LK.`02+I0`,B\_\6],,>@&J[Q4&JJ$!#,JE``Z+[B-`^:4`#PNM
M?4"2(0`&BB$`#<K/_$+3YGD&JB$``HO"`02+KOQ;TR$``HNO_$+3@@$&RLX5
M!:HN``X+0@`%BN5Y!:J,?4"2X;]$J4(`#,I"``V+S?U;TZT5#JK0?$"2(0`$
MBT(``8O!``7*30`-"R$`#HHA`!#*QOU"T^(!!(O.>`ZJ(0`,BZ_]6].F?$"2
M(0`"B^\5#:JB``[*I?U"TR\`#PNE>`VJ0@`-BN&W1:E"``;*0@`0B^S]6].,
M%0^J\/U"TR$`!(M"``&+P0$%RB$`#XK.?4"2(0`.RDP`#`L/>@^JH@$$BR$`
M!HN-_5O3(0`"BZ(`#\I"``R*I7Q`DD(`!<JM%0RJ0@`.BRT`#0OPNT:IAOU"
MT\9X#*JA_5O3+!0-JN$!!LHA``V*[WU`DB$`#\H0`@2+(0`%BT(`$(NP_4+3
M3``,"PUZ#:K"`02+(0`"B\(`#<I"``R*QGQ`DD(`!LJ._5O30@`/B\X5#*KP
MOT>I+@`."X7]0M.E>`RJP?U;TRP4#JJA`07*(0`.BJU]0)(0`@2+(0`-RD(`
M$(O0_4+33``,"PYZ#JKB`02+(0`&BR$``HNB``[*0@`,BJ5\0))"``7*C_U;
MTT(`#8OO%0RJ\+=(J2\`#PN&_4+3QG@,JN']6],L%`^JP0$&RB$`#XK.?4"2
M$`($BR$`#LI"`!"+\/U"TTP`#`L/>@^JH@$$BR$`!8LA``*+P@`/RD(`#(K&
M?$"20@`&RHW]6]-"``Z+K14,JO"[2:DM``T+A?U"TZ5X#*JA_5O3+!0-JN$!
M!<HA``V*[WU`DA`"!(LA``_*0@`0B[#]0M-,``P+#7H-JL(!!(LA``:+(0`"
MBZ(`#<J._5O3I7Q`DD(`#(K.%0RJ0@`%RBX`#@M"``^+AOU"T^&_2JG,>`RJ
MQOU;T\84#JHA``2+Y`$$BT(``8NA`0S*(0`.BJU]0)(A``W*S_U"T](``@ON
M>0ZJ(0`%BT)`)HOO7T#Y(0`$BX0!#LI%_EO3A``"2J44$JKB`0.+A``-BTW^
M0M.P``$+LGD2JH0``HOB8T#Y(4`EB\4!$LH&_EO3I0`!2L84$*I!``.+#?Y"
MTZ)`+(O/``0+K7D0JD(``8OA9T#YA$`FBT8"#<KE_5O3Q``$2J44#ZHF``.+
M@4`NB[$``@LA``:+[/U"TT)`)8OF:T#YCWD/JJ4!#\HD_EO3A!01JJ4``DK"
M``.+)OY"TY```0O1>!&JYF]`^2%`)(OD`1'*K$`RBX0``4H%_EO3I100JH(!
M`HO!``.+#/Y"TX9`+8NN``(+D'D0JL$``8OF<T#Y0D`EBR4"$,K$_5O3H@`"
M2H04#JK&``.+0D`OB\S]0M.-``$+CGD.JD(`!HOF=T#Y(4`DBP0"#LJE_5O3
M@0`!2J44#:K&``.+(4`QBZ\``@LA``:+K/U"TT)`)8OF>T#YC7D-JL4!#<KD
M_5O3A!0/JJ4``DK"``.+YOU"TY$``0O/>`^JYG]`^2%`)(ND`0_*K$`PBX0`
M`4HE_EO3I101JH(!`HO!``.++/Y"TX9`+HNP``(+C'D1JL$``8OF@T#Y0D`E
MB^4!#,H$_EO3H@`"2H04$*K&``.+0D`MBPW^0M..``$+0@`&BZ9Y$*KPAT#Y
M(4`DBX0!!LK%_5O3@0`!2J44#JH0`@.+(4`OBZT``@LA`!"+S_U"TT)`)8OP
MBT#Y[GD.JL4`#LJD_5O3A!0-JJ4``DH"`@.+L/U"TX\``0L->@VJ\(]`^2%`
M)(O$`0W*K$`LBX0``4KE_5O3I10/JH9`)HL!`@.+@@$"B_#]0M.L``(+P0`!
MBP9Z#ZKPDT#Y0D`EBZ4!!LJ$_5O3H@`"2H04#*H0`@.+0D`NBX[]0M./``$+
MS'D,JD(`$(OPET#Y(4`DB\0`#,KE_5O3@0`!2J44#ZH0`@.+(4`MB^W]0M.N
M``(+KWD/JB$`$(OPFT#Y0D`EBX4!#\K$_5O3H@`"2H04#JI"0":+!0(#B]#]
M0M.-``$+10`%BP)Z#JKPGT#Y(4`DB^0!`LJF_5O3A``!2L84#:H!`@.+A$`L
MB[#]0M.$``&+`7H-JLX`!0NE0":+1@`!RL4`!4K,_5O3I4`OB\_]0M.,%0ZJ
M[GD.JO`_5*F-`00+A$`LBZ;]6]/&%`VJ$`(#BZ4`$(LP``[*S``%"Q`"!$H"
M0B*+Y`$#B[#]0M./_5O3#7H-JN\5#*I"``2+I4`FB^2K0/E"``\+Q@$-RL4`
M!4J#``.+AOU"TZ%`(8M$_%O3S'@,JH04`JHA``.+(0`$"Z,!#*KDKT#YA0$-
M"F,``HI/_$+38P`%JH:;E])FX['RXGD"JH0`!HMC0"Z+)?Q;TR[\0M.E%`&J
M8P`$BX0!`JIC``4+A``!BL%Y`:KE.U:I3P`,"H0`#ZIO_$+3A$`MBVW\6].M
M%0.JI0`&B\X!!HN$``6+10`!JH0`#0NE``.*+0`""J4`#:J-_%O3I4`LB^QY
M`ZJE``Z+HQ4$JBT`#*JC``,+[KM`^:4!!(J-`0$*C_Q"TZ4`#:K.`0:+I4`B
MBVW\6]/B>02JK14#JH0!`JJE``Z+[K]`^:4`#0N$``.*30`,"H0`#:IO_$+3
MS@$&BX1`(8NM_%O3X7D#JJT5!:J$``Z+A``-"T,``:KMPT#Y+@`""F,`!8JO
M_$+38P`.JN5Y!:JM`0:+8T`LBX[\6],L``6JSA4$JF,`#8OMQT#Y8P`."XP!
M!(JN``$*C`$.JH[\0M."02*+K`$&BVW\6]/$>02JK14#JD(`#(M"``T+K``$
MJNW+0/F.``4*C`$#BF_\0M.,`0ZJXWD#JJT!!HN!02&+3OQ;TXP``ZK.%0*J
M(0`-BR$`#@N,`0**;@`$"HP!#JI._$+3PGD"JH5!)8OMNUFI+_Q"TZP!!HLM
M_%O3K14!JJ4`#(ML``*JI0`-"XP!`8I-``,*C`$-JN%Y`:K.`0:+A$$DBZW\
M6]-,``&JK14%JH0`#HONUT#YA``-"XP!!8HM``(*C`$-JJ_\0M/.`0:+@T$C
MBXW\6]/L>06JK14$JB4`#*IC``Z+I0`$BN[;0/EC``T+C0$!"H_\0M.E``VJ
MY'D$JLX!!HNB0"*+;?Q;TX4!!*JM%0.J0@`.B^[?0/E"``T+I0`#BHT`#`IO
M_$+3I0`-JLX!!HNA0"&+3?Q;T^5Y`ZJM%0*J@P`%JB$`#HM._$+3(0`-"V,`
M`HK">0*JKP`$"NT[7*EC``^J;$`LBR/\6]-C%`&J+_Q"TZT!!HN,`0V+K0`"
MJH,!`PNL`0&*30`%"N%Y`:J,`0VJ;?Q;TX1!)(O,`0:+A``,BTP``:HN``(*
MC`$#BHP!#JJM%0.JA4$EBX0`#0OO,UVI;?Q"TZUY`ZJ._%O3SA4$JN\!!HNC
M``^+)0`-JF,`#@NE``2*K@$!"J4`#JJ._$+3Q'D$JJ)`(HN%`0:+;/Q;TXP5
M`ZI"``6+;OQ"TZ4!!*I"``P+I0`#BL-Y`ZJ/``T*[#M>J:4`#ZJE0"&+0?Q;
MTR$4`JI/_$+3C`$&BZ4`#(N,``.JI0`!"XP!`HIA``0*XGD"JHP!`:I0``,*
M@4$MB\T!!HNL_%O3(0`-BXP5!:IM``*J[_M`^8X!`0NM`06*+$`LBZT!$*K0
M_4+3I$$DB^T!!HNO_$+3QOU;T\84#JJ$``V+[7D%JM(`!`OO_T#Y00`-RB$`
M#$K%.IC214RY\B%`(XOL`06+0_Y;TPYZ#JIC%!*J(0`,BX1`)HOL`T'Y<0`!
M"Z8!#LHA0".+Q``$2H8!!8N"0"*+3/Y"TR3^6].2>1*JA!01JD(`!HOL!T'Y
MD``""\,!$LHF_D+38P`!2H$!!8ML0"V+`_Y;T]%X$:J,`0&+8Q00JD)`)(OF
M"T'Y;P`,"T0"$<J#02.+A``"2N']6]/"``6+AD`NBP3^0M/&``*+D'@0JB$4
M#ZKD#T'Y+@`&"R("$,KL_4+30@`#2H,`!8M$0#*+POU;TX]Y#ZJ$``.+0A0.
MJL%`(8OC$T'Y30`$"P8"#\K,_4+3P0`!2F8`!8LC0#&+H?U;TXYY#JIC``:+
M(10-JNP!#LKF%T'Y,@`#"X)`(HMA0"&+@@$"2L0`!8M,0#"+IOU"TT+^6]/-
M>`VJA`$$BT(4$JKF&T'Y40`$"\,!#<I,_D+380`!2L,`!8LF0"^+(?Y;T\,`
M`XN,>1*J(101JH)`(HOF'T'Y,``#"Z0!#,IA0"&+@@`"2L8`!8M$0"Z++OY"
MTP+^6].$``:+0A00JL9Y$:KN(T'Y3P`$"X,!!LJ"0"*+80`!2LX!!8LC0"V+
M#?Y"T^']6].P>1"J8P`.BR$4#ZKN)T'Y+0`#"\0`$,IA0"&+@@`"2L0!!8M,
M0"R+[OU"TZ+]6]//>0^JA`$$BT(4#:KL*T'Y3@`$"P,"#\J"0"*+80`!2H,!
M!8LF0":+K/U"T\']6]/#``.+(10.JH9Y#:KL+T'Y+0`#"^0!!LIA0"&+@@`"
M2HP!!8M$0#"+T/U"TZ+]6],.>@ZJA``,BT(4#:KL,T'Y40`$"\,`#LJ"0"*+
M80`!2HP!!8LC0"^+K_U"TR'^6]/M>0VJ8P`,BR$4$:KL-T'Y,``#"\0!#<HO
M_D+3@@`"2H0!!8M,0":+`OY;TX8!!(M"%!"J['D1JF%`(8OD.T'Y3P`&"Z,!
M#,K"0"*+80`!2H,`!8LD0"Z+#OY"T^']6].$``.+(10/JL-Y$*KP/T'Y+@`$
M"X8!`\J!0"&+P@`"2A`"!8M&0"V+[?U"T\+]6].O>0^J0A0.JL8`$(OM0T'Y
M4``&"V0`#\K"0"*+A``!2J$!!8N,0"R+S?U"TP3^6].,`0&+KGD.JH04$*KA
M1T'YD0`,"^8!#LKG0"^+Q@`"2B(`!8O#0".+(?Y;TV,``HLA%!&J8P`!"P'^
M0M/M2T'Y(7@0JH9!)(O"`0'*9/Q;TZP``+!&``9*A!0#JJ4!!8LB_D+3A``&
MBZ4`!XN&Y4?Y0G@1JB$`"0O+`0L+8P`*"X0`!0M(``@+!`P`J0@$`:D+$`#Y
MX$]!^<$`0/D```'K`0"`TH$``%3]>T"I_X,*D<`#7]8T\_^7_7N_J0`0@-+]
M`P"1^/+_EQ\8`/DF8(32)7&5TL2?F]+#CHK2`CZ<TJ;HK/*E^;WR1!>S\D,&
MHO)">KCR!A0`J00,`:D"?`*I'W@`N?U[P:C``U_6'R`#U1\@`]7]>[RI0GQ`
MD_T#`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#`JKW8P.I!8Q"J0!X0+FD#`(+
MOP`$ZV.4@YIB=$*+I(H"J2`$`#7?_@!Q+08`5-8"`5'8?@93%P<`$?=J>M-W
M`A>+'R`#U6`&0*F`!@"I<P(!D6(.?:F"#@&IX`,5JF(.?JF"#@*I8@Y_J8(.
M`ZFD^_^7?P(7ZX'^_U36&AA+X0,7JN`#%*K"?D"3??+_E[9Z`+GS4T&I]5M"
MJ?=C0ZG]>\2HP`-?UA<(@%+W`@!+WP(7:X#"((O7TI<:^'Y`D^(#&*IO\O^7
MH'I`N>`"``N@>@"Y'P`!<>']_U36`A=+<P(8B^`#%:J&^_^7S___%_<#$ZKC
M__\7'R`#U1\@`]7]>[RI_0,`D?-3`:GS`P&J]`,`JO5;`JEUX@"1X0^`$O<;
M`/E@%D#Y=BI`N7<R0+D`(`-3U@K`6@($`!'W"L!:H<H@.*#"(HM?X`!QC0D`
M5`$(@%(B``)+`0"`4D)\0).<\O^7X`,3JF;[_Y=__@.I?_X$J7_^!:E_-@#Y
M=UH.*>`#$ZI?^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA
M_$C3@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\
M2-.!&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(
MTX$J`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3
M@3H`.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!
M2@`Y81)`^8%.`#GS4T&I]5M"J?<;0/G]>\2HLO+_%P$'@%(B``)+`0"`4D)\
M0)-1\O^7N___%Q\@`]4?(`/5'R`#U?U[O*G]`P"1\U,!J;0``+"48BV1]5L"
MJ;4``+"U0BV1E`(5R_8#`"KW8P.I]P,!JO@#`JJ4_D.3VO'_EW0!`+03`(#2
M'R`#U:-Z<_CB`QBJ<P8`D>$#%ZK@`Q8J8``_UI\"$^LA__]4\U-!J?5;0JGW
M8T.I_7O$J,`#7]8?(`/5P`-?UA\@`]4?(`/5'R`#U:,``+!CL$7Y_O'_%U\D
M`]7]>[^I_0,`D?U[P:C``U_6`0`"```````O=&UP`````"X`````````4$%2
M7U1-4$1)4@```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M55-%4@````!54T523D%-10``````````)7,O)7,````O`````````"]P<F]C
M+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,`````
M`%!!4E]414U0``````````!005)?4%)/1TY!344`````.@`````````E<R5S
M)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4``````````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%27T-,
M14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````4$%2
M7T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````````
M4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#
M3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P
M,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`````````
M<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4R
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA
M<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU
M;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE
M(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H
M;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O
M<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M
M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E
M:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I
M.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I
M9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T
M("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(
M.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE
M(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN
M+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI
M+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D
M8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F
M+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@
M)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@
M/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI
M8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@
M)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI
M.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^
M>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"([
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T
M;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S
M:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=6
M6S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!0
M7U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L
M(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E
M<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U
M;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@
M/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*
M96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@
M9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@
M;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A
M7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?
M1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@
M)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I
M9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N
M('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI
M("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D[
M"F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET
M951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@
M)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=
M*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B
M=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC
M;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?
M5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0[
M"GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA
M;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D
M<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D
M=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A
M=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M
M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO
M9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D
M=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*
M<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD
M969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!
M345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@
M?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R
M*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%
M3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P
M<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-
M17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@
M7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@
M/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%
M1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#
M04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG
M4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%2
M7U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E
M>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6
M>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3
M*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO
M9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`
M7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI
M8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@
M;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?
M<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#
M86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I
M;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P
M<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PHQ.PI?7T5.1%]?"@``<&5R;'AS:2YC`````````%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@``````$;`SL0`0``(0```(2+__]`!@``
MQ(W__R@!```4CO__/`$``$2.__]0`0``A([__V0!``#4CO__B`$``.2.__^<
M`0``V(___P0"``!8D?__9`(``/21__^,`@``^)+__\`"``#TD___^`(``"26
M__],`P``F);__W`#``#4EO__D`,``+27___$`P``N)?__]@#``#DF?__1`0`
M`!2:__]8!```-)K__VP$``!8G___J`0``.B?___,!```"*#__^P$```TH?__
M*`4``'2H___,!0``Y*K__P0&```TK/__=`8``+B\__^8!@``%+W__[@&```T
MOO__\`8``-2___\D!P``5,#__U@'``!DP/__;`<``!```````````7I2``1X
M'@$;#!\`$````!@```"4C/__/`````!!!QX0````+````-",__\P````````
M`!````!`````[(S__SP`````````(````%0````8C?__2`````!!#B"=!)X#
M0I,"3M[=TPX`````$````'@```!$C?__!`````````!D````C````$"-___T
M`````$$.0)T(G@="DP:4!4*8`9<"1I8#E016UM5!V-=#WMW3U`X`00Y`DP:4
M!94$E@.7`I@!G0B>!T_6U4'8UT'>W=/4#@!!#D"3!I0%G0B>!T*7`I@!0MC7
M`%P```#T````S(W__X`!````00[0`9T:GAE(E!>3&$34TTC>W0X`00[0`9,8
ME!>=&IX91)@3EQ1$EA65%G(*U--!UM5!V-=!"TG3U-76U]A!E!>3&$&6%946
M09@3EQ0``"0```!4`0``[([__YP`````00ZP`9T6GA5%DQ17"M[=TPX`00L`
M```P````?`$``&"/__\$`0```$$.()T$G@-"DP)?"M[=TPX`0@M4"M[=TPX`
M00M&WMW3#@``-````+`!```PD/___`````!"#L`@0YV(!)Z'!$.3A@24A01"
ME80$EH,$<0K=WM76T]0.`$$+``!0````Z`$``/20__\L`@```$$.8)T,G@M#
MDPJ4"4R5")8'EP:8!7\*WMW7V-76T]0.`$$+29H#F01?"MK900M)V=I"F02:
M`T/9VD&:`YD$0MK9```@````/`(``-"2__]T`````$$.()T$G@-"DP)2WMW3
M#@`````<````8`(``""3__\X`````$$.$)T"G@%&WMT.`````#````"``@``
M/)/__^``````0@[00$.=B@B>B0A#DX@(E(<(0I6&"&P*W=[5T]0.`$$+```0
M````M`(``.B3__\$`````````&@```#(`@``V)/__R@"````0@[@(4*=G`2>
MFP1#DYH$E)D$0Y68!):7!%T*W=[5UM/4#@!!"T*8E027E@1*FI,$F90$>`K8
MUT':V4$+5=C70=K909>6!)B5!$'8UT*8E027E@1!FI,$F90$`!`````T`P``
MF)7__R@`````````$````$@#``"TE?__'``````````X````7`,``,"5__\D
M!0```$$.D`&=$IX11I,0E`]#E0Z6#427#)@+F0H#(0$*WMW9U]C5UM/4#@!!
M"P`@````F`,``*B:__^0`````$$.,)T&G@5$DP10"M[=TPX`00L<````O`,`
M`!2;__\@`````$$.$)T"G@%&WMT.`````#@```#<`P``%)O__RP!````00Y`
MG0B>!T:3!I0%E026`U@*WMW5UM/4#@!!"TT*WMW5UM/4#@!!"P```*`````8
M!```!)S__S@'````0@ZP@P)"G;0@GK,@0Y>N()BM($.3LB"4L2!"E;`@EJ\@
M7)JK()FL($&<J2";JB`":0K:V4'<VT'=WM?8U=;3U`X`00L"FMG:V]Q0W=[7
MV-76T]0.`$$.L(,"D[(@E+$@E;`@EJ\@EZX@F*T@F:P@FJL@FZH@G*D@G;0@
MGK,@`HO9VMO<09JK()FL($&<J2";JB``-````+P$``"@HO__:`(```!!#E"=
M"IX)0Y,(E`="E0:6!4.7!)@#`FX*WMW7V-76T]0.`$$+```X````]`0``-BD
M__]0`0```$$.0)T(G@=$DP:4!4*5!)8#9`K>W=76T]0.`$$+4PK>W=76T]0.
M`$$+```P````,`4``#R%__\D`@```$$.8)T,G@M%DPJ4"94(E@<"80K>W=76
MT]0.`$$+````````(````&0%``"XI?__A!````!!#J`%1IU4GE,#&`0*W=X.
M`$$+'````(@%```8MO__5`````!!#A"=`IX!4][=#@`````T````J`4``%2V
M__\8`0```$$.0)T(G@=#DP:4!4.5!)8#0Y<"F`%G"M[=U]C5UM/4#@!!"P``
M`#````#@!0``/+?__Y0!````00Y`G0B>!T*3!I0%0Y4$E@-#EP("50K>W=?5
MUM/4#@!!"P`P````%`8``*BX__]\`````$$.0)T(G@="DP:4!4.5!)8#19<"
MF`%3WMW7V-76T]0.````$````$@&``#TN/__!``````````0````7`8``/"X
M__\,````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#0(P```````(`C````````8*L!
M```````!`````````!$#`````````0`````````A`P````````$`````````
M,0,````````!`````````#L#````````#`````````!P'`````````T`````
M````;%4````````9`````````%"K`0``````&P`````````(`````````!H`
M````````6*L!```````<``````````@`````````]?[_;P````"@`@``````
M``4`````````,`X````````&`````````$`$````````"@````````#&!```
M``````L`````````&``````````5`````````````````````P````````"(
MK0$```````(`````````H`4````````4``````````<`````````%P``````
M``#0%@````````<`````````,!0````````(`````````*`"````````"0``
M```````8`````````!@```````````````````#[__]O``````$```@`````
M_O__;P````#0$P```````/___V\``````P````````#P__]O`````/82````
M````^?__;P`````0````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````D!P```````"0'```
M`````)`<````````D!P```````"0'````````)`<````````D!P```````"0
M'````````)`<````````D!P```````"0'````````)`<````````D!P`````
M``"0'````````)`<````````D!P```````"0'````````)`<````````D!P`
M``````"0'````````)`<````````D!P```````"0'````````)`<````````
MD!P```````"0'````````)`<````````D!P```````"0'````````)`<````
M````D!P```````"0'````````)`<````````D!P```````"0'````````)`<
M````````D!P```````"0'````````)`<````````D!P```````"0'```````
M`)`<````````D!P```````"0'````````)`<````````D!P```````"0'```
M`````)`<````````D!P```````"0'````````)`<````````D!P```````"0
M'````````)`<````````D!P```````"0'````````)`<````````D!P`````
M``"0'````````)`<````````:*L!``````!050``````````````````````
M````````````````````````````````````````````````````````````
M``````````#05```````````````````@"``````````````````````````
M`````````````````````````/____\`````B%4```````"050``````````
M````````F%4```````"H50```````+!5````````N%4```````#`50``````
M````````````R%4```````#050``````````````````2%D```````!'0T,Z
M("A'3E4I(#$P+C(N,2`R,#(P,3$R-2`H04Q4(%-I<WEP:'5S(#$P+C(N,2UA
M;'0R*0!'0T,Z("A'3E4I(#$P+C(N,2`R,#(Q,#,Q,R`H04Q4(%-I<WEP:'5S
M(#$P+C(N,2UA;'0S*0`M22`N+B]I;F-L=61E`"U)("]U<W(O<W)C+U)032]"
M54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M86%R8V@V-"UL:6YU>"]C<W4`
M+4D@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,S(M86QT,B]B=6EL9"UA
M87)C:#8T+6QI;G5X`"U)("XN+W-Y<V1E<',O=6YI>"]S>7-V+VQI;G5X+V%A
M<F-H-C0`+4D@+BXO<WES9&5P<R]A87)C:#8T+VYP=&P`+4D@+BXO<WES9&5P
M<R]U;FEX+W-Y<W8O;&EN=7@O9V5N97)I8P`M22`N+B]S>7-D97!S+W5N:7@O
M<WES=B]L:6YU>"]W;W)D<VEZ92TV-``M22`N+B]S>7-D97!S+W5N:7@O<WES
M=B]L:6YU>"]I;F-L=61E`"U)("XN+W-Y<V1E<',O=6YI>"]S>7-V+VQI;G5X
M`"U)("XN+W-Y<V1E<',O;G!T;``M22`N+B]S>7-D97!S+W!T:')E860`+4D@
M+BXO<WES9&5P<R]G;G4`+4D@+BXO<WES9&5P<R]U;FEX+VEN970`+4D@+BXO
M<WES9&5P<R]U;FEX+W-Y<W8`+4D@+BXO<WES9&5P<R]U;FEX`"U)("XN+W-Y
M<V1E<',O<&]S:7@`+4D@+BXO<WES9&5P<R]A87)C:#8T+V9P=0`M22`N+B]S
M>7-D97!S+V%A<F-H-C0O;75L=&EA<F-H`"U)("XN+W-Y<V1E<',O86%R8V@V
M-``M22`N+B]S>7-D97!S+W=O<F1S:7IE+38T`"U)("XN+W-Y<V1E<',O:65E
M93<U-"]L9&)L+3$R.``M22`N+B]S>7-D97!S+VEE964W-30O9&)L+38T+W=O
M<F1S:7IE+38T`"U)("XN+W-Y<V1E<',O:65E93<U-"]D8FPM-C0`+4D@+BXO
M<WES9&5P<R]I965E-S4T+V9L="TS,@`M22`N+B]S>7-D97!S+VEE964W-30`
M+4D@+BXO<WES9&5P<R]G96YE<FEC`"U)("XN`"U)("XN+VQI8FEO`"U)("X`
M+4U$("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M
M86%R8V@V-"UL:6YU>"]C<W4O86)I+6YO=&4N9``M348@+W5S<B]S<F,O4E!-
M+T)524Q$+V=L:6)C+3(N,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+V-S
M=2]A8FDM;F]T92YO+F1T`"U-4``M350@+W5S<B]S<F,O4E!-+T)524Q$+V=L
M:6)C+3(N,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]A8FDM;F]T
M92YO`"U$(%-404-+7U!23U1%0U1/4E],159%3#TP`"U5(%]&3U)424997U-/
M55)#10`M1"!?3$E"0U]2145.5%)!3E0`+40@34]$54Q%7TY!344];&EB8P`M
M1"!024,`+40@5$]07TY!34534$%#13UG;&EB8P`M:6YC;'5D92`O=7-R+W-R
M8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M;&EN
M=7@O;&EB8RUM;V1U;&5S+F@`+6EN8VQU9&4@+BXO:6YC;'5D92]L:6)C+7-Y
M;6)O;',N:`!A8FDM;F]T92YC`"UF<W1A8VLM8VQA<V@M<')O=&5C=&EO;@`M
M;6QI='1L92UE;F1I86X`+6UA8FD];'`V-``M875X8F%S92US=')I<"`O=7-R
M+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M
M;&EN=7@O8W-U+V%B:2UN;W1E+F\`+6<`+4\R`"U786QL`"U7=W)I=&4M<W1R
M:6YG<P`M5W5N9&5F`"U797)R;W(`+5=S=')I8W0M<')O=&]T>7!E<P`M5V]L
M9"US='EL92UD969I;FET:6]N`"US=&0]9VYU,3$`+69G;G4X.2UI;FQI;F4`
M+69R96-O<F0M9V-C+7-W:71C:&5S`"UF;65R9V4M86QL+6-O;G-T86YT<P`M
M9G)O=6YD:6YG+6UA=&@`+69S=&%C:RUP<F]T96-T;W(M<W1R;VYG`"UF;6%T
M:"UE<G)N;P`M9G!I90`M9FYO+7-T86-K+7!R;W1E8W1O<@`M9G1L<RUM;V1E
M;#UI;FET:6%L+65X96,`+4U$("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR
M+C,R+6%L=#(O8G5I;&0M86%R8V@V-"UL:6YU>"]C<W4O:6YI="YD`"U-1B`O
M=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H
M-C0M;&EN=7@O8W-U+VEN:70N;RYD=``M350@+W5S<B]S<F,O4E!-+T)524Q$
M+V=L:6)C+3(N,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]I;FET
M+F\`+6%U>&)A<V4M<W1R:7`@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N
M,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]I;FET+F\`+4D@+W5S
M<B]L;V-A;"]I;F-L=61E`"U)("]U<W(O;&EB-C0O<&5R;#4O0T]210`M1"!?
M4D5%3E1204Y4`"U$(%]'3E5?4T]54D-%`"U$(%],05)'149)3$5?4T]54D-%
M`"U$(%]&24Q%7T]&1E-%5%]"2513/38T`"U$($Q$3$E"4%1(3D%-13TB3$1?
M3$E"4D%265]0051((@`M1"!005),7T5813TB<&%R;"(`+40@4$%27U!!0TM%
M4E]615)324]./2(Q+C`U,B(`;6%I;BYC`"UF=W)A<'8`+69N;RUS=')I8W0M
M86QI87-I;F<`+40@0EE414]21$52/3!X,3(S-#4V-S@`+40@538T5%E013UU
M;G-I9VYE9"!L;VYG`'-H83$N8P`M340@+W5S<B]S<F,O4E!-+T)524Q$+V=L
M:6)C+3(N,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+V-S=2]E;&8M:6YI
M="YD`"U-1B`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U
M:6QD+6%A<F-H-C0M;&EN=7@O8W-U+V5L9BUI;FET+F]3+F1T`"U-5"`O=7-R
M+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M
M;&EN=7@O8W-U+V5L9BUI;FET+F]3`"U$($Q)0D-?3D].4TA!4D5$/3$`96QF
M+6EN:70N8P`M875X8F%S92US=')I<"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI
M8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M;&EN=7@O8W-U+V5L9BUI;FET
M+F]3`"UF4$E#`"U)("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L
M=#(O8G5I;&0M86%R8V@V-"UL:6YU>"]N<'1L`"U-1"`O=7-R+W-R8R]24$TO
M0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M;&EN=7@O;G!T
M;"]P=&AR96%D7V%T9F]R:RYD`"U-1B`O=7-R+W-R8R]24$TO0E5)3$0O9VQI
M8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M;&EN=7@O;G!T;"]P=&AR96%D
M7V%T9F]R:RYO4RYD=``M350@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N
M,S(M86QT,B]B=6EL9"UA87)C:#8T+6QI;G5X+VYP=&PO<'1H<F5A9%]A=&9O
M<FLN;U,`<'1H<F5A9%]A=&9O<FLN8P`M875X8F%S92US=')I<"`O=7-R+W-R
M8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%A<F-H-C0M;&EN
M=7@O;G!T;"]P=&AR96%D7V%T9F]R:RYO4P``"````!```````0``1T$D`3-A
M,0`0(P```````-0C````````"````!```````0``1T$D`3-A,0!L50``````
M`&Q5`````````"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F
M<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y'0T,N8V]M;6%N9"YL
M:6YE`"YG;G4N8G5I;&0N871T<FEB=71E<P``````````````````````````
M````````````````````````````````````````````````````````````
M``L````!`````@`````````X`@```````#@"````````'0``````````````
M``````$````````````````````3````!P````(`````````6`(```````!8
M`@```````"0````````````````````$````````````````````)@````<`
M```"`````````'P"````````?`(````````@````````````````````!```
M`````````````````#0```#V__]O`@````````"@`@```````*`"````````
MH`$````````%``````````@````````````````````^````"P````(`````
M````0`0```````!`!````````/`)````````!@````,````(`````````!@`
M````````1@````,````"`````````#`.````````,`X```````#&!```````
M`````````````0```````````````````$X```#___]O`@````````#V$@``
M`````/82````````U``````````%``````````(``````````@````````!;
M````_O__;P(`````````T!,```````#0$P```````&``````````!@````,`
M```(````````````````````:@````0````"`````````#`4````````,!0`
M``````"@`@````````4`````````"``````````8`````````'0````$````
M0@````````#0%@```````-`6````````H`4````````%````%@````@`````
M````&`````````!^`````0````8`````````<!P```````!P'````````!@`
M```````````````````$````````````````````>0````$````&````````
M`)`<````````D!P```````#@`P``````````````````$```````````````
M`````(0````!````!@````````"`(````````(`@````````[#0`````````
M`````````$````````````````````"*`````0````8`````````;%4`````
M``!L50```````!0````````````````````$````````````````````D```
M``$````"`````````(!5````````@%4```````!Z/P``````````````````
M"````````````````````)@````!`````@````````#\E````````/R4````
M````%`$```````````````````0```````````````````"F`````0````(`
M````````$)8````````0E@```````'`&```````````````````(````````
M````````````L`````X````#`````````%"K`0``````4*L````````(````
M````````````````"``````````(`````````+P````/`````P````````!8
MJP$``````%BK````````"`````````````````````@`````````"```````
M``#(`````0````,`````````8*L!``````!@JP````````@`````````````
M```````(````````````````````U0````8````#`````````&BK`0``````
M:*L````````@`@````````8`````````"``````````0`````````-X````!
M`````P````````"(K0$``````(BM````````>`(```````````````````@`
M````````"`````````#C`````0````,``````````+`!````````L```````
M`'@````````````````````(````````````````````Z0````@````#````
M`````'BP`0``````>+`````````H$```````````````````"```````````
M`````````.X````!````,````````````````````'BP````````;```````
M``````````````$``````````0````````#W`````0```#``````````````
M``````#DL````````-,+```````````````````!``````````$`````````
M"0$```<``````````````*#``0``````N+P```````!(````````````````
M````!`````````````````````$````#``````````````````````````"]
F````````'P$```````````````````$`````````````````````
